==> struts2-jquery-plugin-3.1.0-sources.jar: com/jgeppert/struts2/jquery/views/jsp/ui/CheckboxListTag.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package com.jgeppert.struts2.jquery.views.jsp.ui;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.struts2.components.Component;

import com.jgeppert.struts2.jquery.components.CheckboxList;
import com.opensymphony.xwork2.util.ValueStack;

/**
 * 
 * @see CheckboxList
 * @author <a href="http://www.jgeppert.com">Johannes Geppert</a>
 * 
 */
public class CheckboxListTag extends AbstractFormListElementTag {

  private static final long serialVersionUID = 1792119547676464144L;

  protected String          buttonset;

  public Component getBean(ValueStack stack, HttpServletRequest req, HttpServletResponse res)
  {
    return new CheckboxList(stack, req, res);
  }

  protected void populateParams()
  {
    super.populateParams();

    CheckboxList checkboxList = (CheckboxList) component;
    checkboxList.setButtonset(buttonset);
  }

  public void setButtonset(String buttonset)
  {
    this.buttonset = buttonset;
  }
}

==> struts2-jquery-plugin-4.0.3-sources.jar: com/jgeppert/struts2/jquery/views/jsp/ui/CheckboxListTag.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package com.jgeppert.struts2.jquery.views.jsp.ui;

import com.jgeppert.struts2.jquery.components.CheckboxList;
import com.opensymphony.xwork2.util.ValueStack;
import org.apache.struts2.components.Component;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 * @author <a href="http://www.jgeppert.com">Johannes Geppert</a>
 * @see CheckboxList
 */
public class CheckboxListTag extends AbstractFormListElementTag {

    private static final long serialVersionUID = 1792119547676464144L;

    protected String buttonset;
    protected String icon;
    protected String direction;

    public Component getBean(ValueStack stack, HttpServletRequest req, HttpServletResponse res) {
        return new CheckboxList(stack, req, res);
    }

    protected void populateParams() {
        super.populateParams();

        CheckboxList checkboxList = (CheckboxList) component;
        checkboxList.setButtonset(buttonset);
        checkboxList.setIcon(icon);
        checkboxList.setDirection(direction);
    }

    public void setButtonset(String buttonset) {
        this.buttonset = buttonset;
    }

    public void setIcon(String icon) {
        this.icon = icon;
    }

    public void setDirection(String direction) {
        this.direction = direction;
    }
}
